@@ -82,21 +82,22 @@ class Transaction(object):
         """
         return bool(self.ops)
 
-    def perform_ops(self, cursor):
+    def perform_ops(self):
         """
-        Performs the stored operations on the given
-        cursor object.
-
-        :param cursor: The SQLite.Cursor object.
+        Performs the stored operations on the database
+        connection. Only to be called when within a
+        lock and a database transaction by the
+        ``commit`` method.
         """
-        cursor.execute('BEGIN')
-        for operation, edges in self.ops:
-            for edge in edges:
-                cursor.execute(*operation(
-                    src=edge.src,
-                    rel=edge.rel,
-                    dst=edge.dst,
-                ))
+        with self.db:
+            with closing(self.db.cursor()) as cursor:
+                for operation, edges in self.ops:
+                    for edge in edges:
+                        cursor.execute(*operation(
+                            src=edge.src,
+                            rel=edge.rel,
+                            dst=edge.dst,
+                        ))
 
     def commit(self):
         """
@@ -107,6 +108,4 @@ class Transaction(object):
         committed twice.
         """
         with self.lock:
-            with self.db:
-                with closing(self.db.cursor()) as cursor:
-                    self.perform_ops(cursor)
+            self.perform_ops()
