@@ -1,3 +1,4 @@
+import pytest
 from graphlite import V
 from sqlite3 import ProgrammingError
 
@@ -8,8 +9,5 @@ def test_contains(graph):
 
 def test_close(graph):
     graph.close()
-    try:
+    with pytest.raises(ProgrammingError):
         graph.db.execute('INSERT INTO knows (src,dst) VALUES (1,1)')
-        raise AssertionError
-    except ProgrammingError:
-        pass
