@@ -36,3 +36,14 @@ def test_count(graph):
 def test_slice(graph):
     assert len(list(graph.find(V(1).knows)[:1])) == 1
     assert list(graph.find(V(1).knows)[1:]) == [3, 4]
+    assert list(graph.find(V(1).knows)[::2]) == [2, 4]
+
+
+def test_to(graph):
+    assert graph.find(V(1).knows).to(list) == [2, 3, 4]
+    assert graph.find(V(1).knows).to(set) == set((2, 3, 4))
+
+
+def test_edge():
+    assert V(1).knows(2) == V(1).knows(2)
+    assert V(1).knows(3) != V(1).knows(2)
