@@ -1,10 +1,11 @@
+import pytest
 from graphlite import V
 from graphlite.transaction import AbortSignal
 from sqlite3 import OperationalError
 from threading import Thread
 
 
-def test_concurrency(graph):
+def test_transaction_concurrency(graph):
     stored = [V(1).knows(i) for i in range(5, 9)]
 
     def store(value):
@@ -21,27 +22,27 @@ def test_concurrency(graph):
         assert item in graph
 
 
-def test_delete(graph):
+def test_transaction_delete(graph):
     queries = [
         V(1).knows(2),
         V(1).likes,
         V().knows(3),
         V().knows,
     ]
-    assertions = [
-        lambda: V(1).knows(2) not in graph,
-        lambda: V(1).likes(2) not in graph,
-        lambda: V(1).knows(3) not in graph,
-        lambda: V(1).knows(4) not in graph,
+    edges = [
+        V(1).knows(2),
+        V(1).likes(2),
+        V(1).knows(3),
+        V(1).knows(4),
     ]
 
-    for assertion, query in zip(assertions, queries):
+    for edge, query in zip(edges, queries):
         with graph.transaction() as tr:
             tr.delete(query)
-        assert assertion()
+        assert edge not in graph
 
 
-def test_transaction(graph):
+def test_transaction_store(graph):
     with graph.transaction() as tr:
         tr.store(V(1).knows(7))
         tr.store(V(1).knows(8))
@@ -51,13 +52,12 @@ def test_transaction(graph):
 
 
 def test_transaction_atomic(graph):
-    try:
+    with pytest.raises(OperationalError):
         with graph.transaction() as tr:
             tr.store(V(1).knows(7))
             tr.store(V(1).does(1))
-        raise AssertionError
-    except OperationalError:
-        assert V(1).knows(7) not in graph
+
+    assert V(1).knows(7) not in graph
 
 
 def test_transaction_abort(graph):
@@ -68,7 +68,17 @@ def test_transaction_abort(graph):
     assert V(1).knows(10) not in graph
 
 
-def test_transaction_multiple(graph):
+def test_transaction_nested(graph):
+    with pytest.raises(OperationalError):
+        with graph.transaction() as tr1:
+            with graph.transaction() as tr2:
+                tr2.store(V(1).does(2))
+            tr1.store(V(1).knows(5))
+
+    assert V(1).knows(5) not in graph
+
+
+def test_transaction_many(graph):
     to_delete = (2, 3, 4)
     to_store = (6, 7, 8)
 
